@@ -1,7 +1,7 @@
 use 5.14.0;
 
 package Dist::Zilla::Plugin::MapMetro::MintMapFiles;
-$Dist::Zilla::Plugin::MapMetro::MintMapFiles::VERSION = '0.1200';
+$Dist::Zilla::Plugin::MapMetro::MintMapFiles::VERSION = '0.1300';
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 with 'Dist::Zilla::Role::TextTemplate';
@@ -66,100 +66,15 @@ author = {{ $dist->authors->[0] }}
 license = Perl_5
 copyright_holder = {{ $dist->authors->[0] }}
 
-[Git::GatherDir]
-exclude_filename = Build.PL
-exclude_filename = META.json
-exclude_filename = LICENSE
-exclude_filename = README.md
+[@Iller]
+is_private = 0
 
-[CopyFilesFromBuild]
-copy = META.json
-copy = LICENSE
-copy = Build.PL
-
-[ReversionOnRelease]
-prompt = 1
-
-[OurPkgVersion]
-
-[NextRelease]
-format = %v  %{yyyy-MM-dd HH:mm:ss VVV}d
-
-[PreviousVersion::Changelog]
-[NextVersion::Semantic]
-major =
-minor = API Changes, New Features, Enhancements
-revision = Revision, Bug Fixes, Documentation, Meta
-format = %d.%02d%02d
-numify_version = 0
-
-[Git::Check]
-allow_dirty = dist.ini
-allow_dirty = Changes
-allow_dirty = META.json
-allow_dirty = README.md
-allow_dirty = Build.PL
+NextVersion::Semantic.major =
+NextVersion::Semantic.minor = API Changes, New Features, Enhancements
+NextVersion::Semantic.revision = Revision, Bug Fixes, Documentation, Meta
+NextVersion::Semantic.format = %d.%02d%02d
+NextVersion::Semantic.numify_version = 0
 
 [MapMetro::MakeGraphViz]
 
-[GithubMeta]
-issues = 1
-
-[ReadmeAnyFromPod]
-filename = README.md
-type = markdown
-location = root
-
-[MetaNoIndex]
-directory = t
-directory = xt
-directory = inc
-directory = share
-directory = eg
-directory = examples
-
-[Prereqs::FromCPANfile]
-
-[ModuleBuildTiny]
-
-[MetaJSON]
-
-[ContributorsFromGit]
-
-[Test::EOL]
-[PodSyntaxTests]
-
-[MetaYAML]
-
-[License]
-
-[ExtraTests]
-
-[ShareDir]
-
-[Manifest]
-
-[ManifestSkip]
-
-[CheckChangesHasContent]
-
-[TestRelease]
-
-[ConfirmRelease]
-
-[UploadToCPAN]
-
-[Git::Commit]
-commit_msg = %v
-allow_dirty = dist.ini
-allow_dirty = Changes
-allow_dirty = META.json
-allow_dirty = README.md
-allow_dirty = Build.PL
-
-[Git::Tag]
-tag_format = %v
-tag_message =
-
-[Git::Push]
-remotes_must_exist = 0
+[MapMetro::MakeLinePod]
